#
# spec file for package garage
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           garage
Version:        1.1.0
Release:        1.1
Summary:        S3-compatible object store for small self-hosted geo-distributed deployments
License:        AGPL-3.0-only
URL:            https://git.deuxfleurs.fr/Deuxfleurs/garage
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Source2:        %{name}.service
Source21:       system-user-%{name}.conf
BuildRequires:  cargo >= 1.77
BuildRequires:  cargo-packaging
BuildRequires:  libseccomp-devel
BuildRequires:  sysuser-tools
BuildRequires:  zstd

ExcludeArch:    %{ix86}

%description
Garage is an S3-compatible distributed object storage service designed for
self-hosting at a small-to-medium scale.

Garage is designed for storage clusters composed of nodes running at different
physical locations, in order to easily provide a storage service that
replicates data at these different locations and stays available even when some
servers are unreachable. Garage also focuses on being lightweight, easy to
operate, and highly resilient to machine failures.

%prep
%autosetup -p 1 -a 1

%build
%{cargo_build}

# system-user
%sysusers_generate_pre %{SOURCE21} user

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}

# server systemd unit file
install -D -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service

# configuration in /etc/garage/
install -d -m 0755 %{buildroot}%{_sysconfdir}/%{name}/

# directory in /var/lib/
install -d -m 0755 %{buildroot}%{_sharedstatedir}/%{name}
install -d -m 0755 %{buildroot}%{_sharedstatedir}/%{name}/data/
install -d -m 0755 %{buildroot}%{_sharedstatedir}/%{name}/meta/

# system user
install -Dm644 %{SOURCE21} %{buildroot}%{_sysusersdir}/system-user-%{name}.conf

%pre -f user.pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_unitdir}/%{name}.service
%{_sysusersdir}/system-user-%{name}.conf

%dir %attr(755,root, %{name}) %{_sysconfdir}/%{name}/
%ghost %config(noreplace) %{_sysconfdir}/%{name}/%{name}.toml
%dir %attr(750,%{name}, %{name}) %{_sharedstatedir}/%{name}/
%dir %attr(750,%{name}, %{name}) %{_sharedstatedir}/%{name}/data/
%dir %attr(750,%{name}, %{name}) %{_sharedstatedir}/%{name}/meta/

%changelog
* Wed Mar  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.1.0:
  * Bug fixes
  - Fix free space calculation on FreeBSD (#907, #917)
  - Use a subdirectory for sqlite snapshots (#932)
  - Better handling of errors for more precise error codes (#942)
  - Fix internal function table::insert_many failing with zero
    items (#915, #946)
  - Fix error reporting in garage meta snapshot command (#920,
    [#930])
  - Return stats from all nodes in garage stats -a including
    those not in the layout (#814, #953)
  - Block manager: avoid writing blocks to draining nodes (#815,
    [#956])
  - Avoid deadlock in block rebalance worker (#845, #957)
  - Fix crash in layout computation (#937)
  * S3 compatibility
  - Add support for STREAMING-*-PAYLOAD-TRAILER (#824, #960)
  - Implement x-amz-website-redirect-location header (#966)
  - Implement if-match and if-unmodified-since in
    GetObject/HeadObject (#804, #967)
  - Parse x-id query parameter and report any inconsistency
    (#822, #954)
  - Return a location value in CompleteMultipartUpload (#852,
    [#958])
  - Make x-amz-meta-* headers lowercase (#844, #938)
  * New features
  - Add bucket domain to metrics (#608)
  - Add metadata_snapshots_dir configuration flag (#926, #933)
  - Add use_local_tz configuration flag for lifecycle worker
    (#908)
  * Other
  - Documentation updates (#887, #888, #901, #921, #927, #941)
  - Split build of garage_api in 4 smaller crates (#947)
  - Remove some uses of async_trait (#952)
  - Fix compilation warnings (#959)
  - Replace cargo2nix by crane (#950)
  - Update toolchain and dependencies (#918, #924, #931, #951)
  - Build and CI improvements (#912, #935, #936, #949)
  - Improvements to Helm chart (#896, #923)
  - Fix typos (#898, #928)
  * Changes included after 1.1.0~rc1:
  - admin api definition: fix globalAlias query parameter name
    (#971, #973)
  - kubernetes helm chart: add headless service for statefulSet
    serviceName (#969, #970)
* Thu Nov 21 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints to avoid OOM failures
* Fri Sep 27 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.0.1:
  * Features:
  - Add rpc_public_addr_subnet configuration option (#817)
  - Improve LMDB performance (#855)
  - Improve metadata performance (#873, #877)
  * Bug fixes:
  - Discard old layout info when it is completely out-of-date,
    fixes introducing new nodes in an old cluster (#841, #861)
  - PostObject: don't modify request before validating policy
    (#850)
  - Fix logic in garage layout skip-dead-nodes (#879, #880)
  - Kill opened connections after SIGINT after 10s deadline
    (#806, #864)
  * Other:
  - Update the time dependency to fix builds using Rust 1.80
    (#849, #865)
  - Fix build when lmdb feature is disabled (#800, #863)
  - Improvements to Nix tooling (#816)
  - Improvements to Helm chart (#823, #843)
  - Toolchain updates (#866)
  - Documentation fixes (#799, #802, #831, #875, #803, #862)
  - CLI help and error message improvements (#813, #846)
* Mon Jun 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package garage: S3-compatible object store for small
  self-hosted geo-distributed deployments
